CalculatorWidget class
A stateful widget that builds a calculator UI with full input and output logic.
Supports percentage, basic operators, and backspace. The evaluated result is sent to the parent via onResultCalculated callback.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- CalculatorWidget
Constructors
- CalculatorWidget({required bool isDarkMode, required dynamic onResultCalculated(String result)})
- Constructs a CalculatorWidget.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isDarkMode → bool
-
Whether to use dark mode styling.
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- onResultCalculated → dynamic Function(String result)
-
Callback function to return the calculated result.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< CalculatorWidget> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited